/**
Cabina: La Cabina es el carro del ascensor que sube y baja con personas.
La cabina una referencia a la "caja ascensor" donde se encuentra, su posición actual,
y una referencia al último sensor que activó y que al dejarlo debe desactivarlo.
La causa única de su movimiento es la invocación al método move.
En esta etapa la cabina se moverá en respuesta a las invoaciones a move.
 
Ante un movimiento, la cabina pregunta a la caja del ascensor por sensores en su nueva
posición.  De haber sensor, lo activa. Si no hay sensor se preocupa de desactivar
el último activado.
*/
import java.util.Random;
import java.awt.geom.*;
import java.awt.*;
import java.awt.Container;

public class Cabina
{
	//private BotoneraCabina botonera 			// NOT USED IN THIS STAGE
	private CajaAscensor shaft;
	private float position;					// in meters
	private int floorIndicator;
	private Sensor lastSensor = null;
	private Container container;			// Container where the cabina is contained.
	private View view;
	private CajaAscensorView shaftView;

	public Cabina (CajaAscensor caja, double posX, double width, double height)
	{
		Random generator = new Random();
		shaft = caja;
		position = generator.nextFloat();   //it starts between 0 an 1 [m]
		if(position < 0.1)
			position = 0.1f;
		floorIndicator = 1;
		container = null;
		view = new View(posX, position, width, height);
	}

	public CajaAscensor getShaft()
	{
		return shaft;
	}
	//	NOT USED IN THIS STAGE
	/*public Cabina (BotoneraCabina bc, CajaAscensor caja)
	{
		this(caja,0f,0f,0f);
		botonera = bc;
	}
	
	public void setBotonera( BotoneraCabina bc)
	{
		botonera = bc;
	}*/
	public void move(float delta)
	{
		Sensor sensor;
		position+=delta;
		view.setPosition(position);
		if (container != null)
			shaftView.repaint();

		sensor = shaft.findSensor(position);
		if (sensor != null)	// there is a sensor
		{
			if(sensor != lastSensor)	// it is not the same 
			{
				sensor.activateAction();
				lastSensor = sensor;
			}
		}
		else if (lastSensor != null)	// deactivate previous
		{
			lastSensor.deactivateAction(); 
			lastSensor = null;
		}
	}
	public double getPosition()
	{
		return position;
	}   
	public void setFloorIndicator (int floor)
	{
		floorIndicator = floor;
	}
	public int readFloorIndicator()
	{
		return floorIndicator;
	}

	public void setContainer(Container c, int index)
	{
		container = c;
		shaftView = (CajaAscensorView) c.getComponent(index-1);
	}
	public View getView()
	{
		return view;
	}   
	public class View extends Rectangle2D.Double
	{
		private double xPos, width, height;
		private View(double x, float y, double w, double h)
		{
			xPos = x;
			width = w;
			height = h;
			setPosition(y);
		}
		private void setPosition(float position)
		{
			setFrame(xPos, position, width, height);      
		}
		public void draw (Graphics2D g)
		{
			g.setColor(new Color(138, 239, 148));
			g.fill(this);
			g.setColor(Color.BLACK);
			g.draw(this);
		}
	}
}
