import java.awt.Dimension;
import java.awt.BorderLayout;
import javax.swing.*;

public class MainStage3
{
	public static void main(String[] args)
	{
		// Elevator's parameters
		int numPisos = 5;
		float floorHight = 3.0f;
		float cabinaSpeed = 1f;   // [m/s]
		MyElevatorFrame frame = new MyElevatorFrame(numPisos, floorHight, cabinaSpeed);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setVisible(true);
	}   
}

class MyElevatorFrame extends JFrame
{
	public MyElevatorFrame(int numPisos, float floorHight, float cabinaSpeed)
	{
		setTitle("My Elevator for ELO329");
		setSize(600,800);

		// Creación componentes del ascensor
		Botonera[] botoneras = new Botonera[numPisos+1]; // index goes from 0 to numPisos.
		
		Sensor[] sensores = new Sensor[numPisos];  
		CajaAscensor shaft = new CajaAscensor(sensores);
		Cabina cabina = new Cabina(shaft, 0.065, 1.88, 2.25);
		Motor motor = new Motor(cabina, cabinaSpeed);
		ControlUnit controlUnit = new ControlUnit(motor, cabina, sensores, botoneras);
		BotoneraCabina bc = new BotoneraCabina(numPisos, controlUnit, 0); 	
		cabina.setBotonera(bc);
		bc.setCabina(cabina);

		botoneras[0] = bc;
		botoneras[1] = new BotoneraPrimerPiso(controlUnit,1);
		for (int i=2; i < numPisos; i++)
			botoneras[i] = new BotoneraPisoIntermedio(controlUnit, i);
		botoneras[numPisos] = new BotoneraUltimoPiso(controlUnit, numPisos);

		for (int i=0; i < sensores.length; i++)
			sensores[i] = new Sensor(i*floorHight,i+1, controlUnit, 2.0f);

		// now we organize every object view
		//Container contentPane = getContentPane();
		//contentPane.setLayout(new BoxLayout(contentPane,BoxLayout.X_AXIS));

		JPanel firstPanel = new JPanel();
		firstPanel.setLayout(new BorderLayout());

		firstPanel.add(botoneras[0].getView(), BorderLayout.CENTER);
		Boton b = ((BotoneraCabina) botoneras[0]).getBoton(0);

		firstPanel.setPreferredSize(new Dimension(b.getBtnPreferredSize(), b.getBtnPreferredSize()));

		JPanel secondPanel = new JPanel();		// We create a Panel to store the elevator's cabin and the floor's button
		secondPanel.setLayout(new BoxLayout(secondPanel,BoxLayout.X_AXIS));
		secondPanel.setPreferredSize(new Dimension(400,800));
		
		CajaAscensorView shaftView = new CajaAscensorView(0.0, 0.0, 2.0, 15.5, cabina.getView(), sensores);
		secondPanel.add(shaftView);
		controlUnit.setContainer(secondPanel, secondPanel.getComponentCount());	// so motor can call repaint when it pauses the elevator.
		cabina.setContainer(secondPanel, secondPanel.getComponentCount());	// so cabina can call repaint when it moves.
		
		BotoneraPisosView bpView = new BotoneraPisosView(botoneras);
		secondPanel.add(bpView.getPanel());

		JSplitPane splitPanel = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, firstPanel, secondPanel);
		splitPanel.setDividerLocation(200);

		add(splitPanel);

		motor.lower();
	}

	class BotoneraPisosView
	{
		private JPanel mainPanel;
		BotoneraPisosView(Botonera[] botoneras)
		{
			mainPanel = new JPanel();
			mainPanel.setLayout(new BoxLayout(mainPanel,BoxLayout.Y_AXIS));
			
			boolean isOverFour = (4 < botoneras.length)?true:false;

			for (int i = botoneras.length-1; i > 0; i--)
			{
				JPanel panel = new JPanel();
				panel.setMaximumSize(new Dimension(200,150));
				if(isOverFour)
				{
					int xy = 800/(2*botoneras.length);
					botoneras[i].setBotonNewDimension(xy);
				}
				panel.add(botoneras[i].getView());
				mainPanel.add(panel);
			}
		}
		public JPanel getPanel()
		{
			return mainPanel;
		}
	}
}

