/**
Cabina: La Cabina es el carro del ascensor que sube y baja con personas.
La cabina una referencia a la "caja ascensor" donde se encuentra, su posición actual,
y una referencia al último sensor que activó y que al dejarlo debe desactivarlo.
La causa única de su movimiento es la invocación al método move.
En esta etapa la cabina se moverá en respuesta a las invoaciones a move.
 
Ante un movimiento, la cabina pregunta a la caja del ascensor por sensores en su nueva
posición.  De haber sensor, lo activa. Si no hay sensor se preocupa de desactivar
el último activado.
*/
import java.util.Random;
import java.awt.Container;

public class Cabina
{
	//#################################
	private BotoneraCabina botonera; 			// NOT USED IN THIS STAGE
	private CajaAscensor shaft;
    private CabinaView view;
	private float position;					// in meters
	private int floorIndicator;
	private Sensor lastSensor = null;

	//#################################
	public Cabina (CajaAscensor caja, double posX, double width, double height)
	{
        shaft = caja;
        floorIndicator = 1;
		Random generator = new Random();
        position = generator.nextFloat();   //it starts between 0 an 1 [m]
		if(position < 0.1)
			position = 0.1f;
		view = new CabinaView(posX, position, width, height);
	}

	//#################################
	public void setBotonera( BotoneraCabina bc)
	{
		botonera = bc;
	}
	public void move(float delta)
	{
		Sensor sensor;
		position+=delta;
		view.setPosition(position);
		sensor = shaft.findSensor(position);
		if (sensor != null)	// there is a sensor
		{
			if(sensor != lastSensor)	// it is not the same 
			{
				sensor.activateAction();
				lastSensor = sensor;
			}
		}
		else if (lastSensor != null)	// deactivate previous
		{
			lastSensor.deactivateAction(); 
			lastSensor = null;
		}
	}
	public void setFloorIndicator (int floor)
	{
		floorIndicator = floor;
		botonera.setFloorIndicator(floor);
	}
	public int readFloorIndicator()
	{
		return floorIndicator;
	}

	public void setContainer(Container c, int index)
	{
	    view.setContainer(c,index);
	}
	public CabinaView getView()
	{
		return view;
	}   

}
