import java.awt.Container;

public class ControlUnit
{
	//#################################
	private Motor motor;
	private Cabina cabina;
	private Sensor[] sensores;
	private Botonera[] botoneras;

	//#################################
	public ControlUnit(Motor m,Cabina ca,Sensor[] s,Botonera[] b)
	{
		motor = m;
		cabina = ca;
		sensores = s;
		botoneras = b;
	}

	//#################################
	public void elevatorRequested()                     // Elevator requested by BotoneraCabina
	{
		if (motor.getState() == Motor.STOPPED)
		{
			int cabinaLocation = cabina.readFloorIndicator();
			updateFloorsView(cabinaLocation);

			int locationRequest = ((BotoneraCabina) botoneras[0]).searchBtnON();

			if (locationRequest != 0)
			{
				if (locationRequest > cabinaLocation)
					motor.lift();
				else if (locationRequest < cabinaLocation)
					motor.lower();
				else
				{ // the cabina is already in that floor.
					checkAndAttendUpRequest(cabinaLocation);
					checkAndAttendDownRequest(cabinaLocation);
					checkAndAttendCabinaRequest(cabinaLocation);
				}
			}
		}
	}
	public void elevatorRequested(int locationRequest)  //Elevator requested by BotoneraPiso
	{
		if (motor.getState() == Motor.STOPPED)
		{
			int cabinaLocation = cabina.readFloorIndicator();
			updateFloorsView(cabinaLocation);
			if (locationRequest > cabinaLocation)
				motor.lift();
			else if (locationRequest < cabinaLocation)
				motor.lower();
			else
			{ // the cabina is already in that floor.
				checkAndAttendUpRequest(cabinaLocation);
				checkAndAttendDownRequest(cabinaLocation);
				checkAndAttendCabinaRequest(cabinaLocation);
			}
		}
	}
	private void checkAndAttendUpRequest(int floor)
	{
		if (botoneras[floor] instanceof UpRequest)
		{
			UpRequest boton = (UpRequest) botoneras[floor];
			if (boton.isUpRequested())
			{
				boton.resetUpRequest();
				motor.pause();
			}
		}
	}
	private void checkAndAttendDownRequest(int floor)
	{
		if (botoneras[floor] instanceof DownRequest)
		{
			DownRequest boton = (DownRequest) botoneras[floor];
			if (boton.isDownRequested())
			{
				boton.resetDownRequest();
				motor.pause();
			}
		}
	}
	private void checkAndAttendCabinaRequest(int floor)
	{
		BotoneraCabina bc = (BotoneraCabina) botoneras[0];
		if (bc.isFloorRequested(floor))
		{
				bc.resetFloorRequest(floor);
				motor.pause();
		}
	}
	public void updateFloorsView(int currentFloor)
	{
		for(Botonera b:botoneras)
		    b.setFloorIndicator(currentFloor);
        for(Botonera b:botoneras)
            b.getView();
	}
	public void activateSensorAction(int currentFloor)
	{
		cabina.setFloorIndicator(currentFloor);
		updateFloorsView(currentFloor);
		checkAndAttendCabinaRequest(currentFloor);
		switch (motor.getState())
		{
			case Motor.UP:
				checkAndAttendUpRequest(currentFloor);
				if(!areThereHigherRequests(currentFloor))
				{
					checkAndAttendDownRequest(currentFloor);
					if (areThereLowerRequests(currentFloor))
						motor.lower();
					else
						motor.stop();
				 }
				 break;
			case Motor.DOWN:
				checkAndAttendDownRequest(currentFloor);
				if(!areThereLowerRequests(currentFloor))
				{
					checkAndAttendUpRequest(currentFloor);
					if (areThereHigherRequests(currentFloor))
						motor.lift();
					else
						motor.stop();
				}
		}
	}
	private boolean areThereHigherRequests(int currentFloor)
	{
		BotoneraCabina bc = (BotoneraCabina) botoneras[0];
		for (int i=currentFloor+1; i < botoneras.length; i++)
		{
			if(botoneras[i] instanceof UpRequest)
			{
				UpRequest boton = (UpRequest) botoneras[i];
				if (boton.isUpRequested()) 
					return true;
			}
			if(botoneras[i] instanceof DownRequest)
			{
				DownRequest boton = (DownRequest) botoneras[i];
				if (boton.isDownRequested()) 
					return true;
			}
			if (bc.isFloorRequested(i))
				return true;
		}
		return false;
	}
	private boolean areThereLowerRequests(int currentFloor)
	{
		BotoneraCabina bc = (BotoneraCabina) botoneras[0];
		for (int i=currentFloor-1; i > 0; i--)
		{
			if(botoneras[i] instanceof UpRequest)
			{ 
				UpRequest boton = (UpRequest) botoneras[i];
				if (boton.isUpRequested()) 
					return true;
			}
			if(botoneras[i] instanceof DownRequest)
			{ 
				DownRequest boton = (DownRequest) botoneras[i];
				if (boton.isDownRequested()) 
					return true;
			}
			if (bc.isFloorRequested(i))
				return true;
		}
		return false;
	}
}