import java.awt.Dimension;
import java.awt.BorderLayout;
import javax.swing.*;

public class MainStage4
{
	public static void main(String[] args)
	{
		// Elevator's parameters
		int 	Pisos 		= 5;
		float 	Altura 		= 3.0f;
		float 	Velocidad 	= 1f;   // [m/s]
		MyElevator_GUI frame= new MyElevator_GUI(Pisos, Altura, Velocidad);
		frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		frame.setVisible(true);
	}   
}

class MyElevator_GUI extends JFrame
{
	public MyElevator_GUI(int n_pisos, float f_height, float c_speed)
	{
		setTitle("My Elevator for ELO329");
		setSize(600,750);
		// Componentes ascensor -----------------
		Botonera[] 	botoneras 	= new Botonera[(n_pisos+1)];
		Sensor[]	sensores	= new Sensor[n_pisos];
		CajaAscensor shaft		= new CajaAscensor(sensores);
		Cabina		cabina		= new Cabina(shaft, 0.065, 1.88, 2.25);
		Motor		motor		= new Motor(cabina, c_speed);
		ControlUnit	controlUnit = new ControlUnit(motor, cabina, sensores, botoneras);
		BotoneraCabina bc 		= new BotoneraCabina(n_pisos, controlUnit, 0);
		//------------------------
		cabina.setBotonera(bc);
		//------------------------
		botoneras[0] = bc;
		botoneras[1] = new BotoneraPrimerPiso(controlUnit, 1);
		botoneras[n_pisos] = new BotoneraUltimoPiso(controlUnit, n_pisos);
		for(int i = 2; i < n_pisos; i++)
			botoneras[i] = new BotoneraPisoIntermedio(controlUnit, i);
		//------------------------
		for(int i = 0; i < sensores.length; i++)
			sensores[i] = new Sensor(i*f_height, i+1, controlUnit, 2.0f);
		// Fin componentes ascensor -------------
		// Creacion del frame -------------------
		ConfigMenuListener MListener = new ConfigMenuListener(motor);
		setJMenuBar(AscensorMenu(MListener));

		JPanel firstpanel = new JPanel();
		firstpanel.setPreferredSize(new Dimension(300,750));
		firstpanel.setLayout(new BorderLayout());
		firstpanel.add(botoneras[0].getView(), BorderLayout.CENTER);

		JPanel secndpanel = new JPanel();
		secndpanel.setLayout(new BoxLayout(secndpanel,BoxLayout.X_AXIS));
		CajaAscensorView shaftView = new CajaAscensorView(0.0, 0.0, 2.0, 15.5, cabina.getView(), sensores);
		secndpanel.add(shaftView);
		cabina.setContainer(secndpanel, secndpanel.getComponentCount());	// so cabina can call repaint when it moves.

		BotoneraPisosView bpView = new BotoneraPisosView(botoneras);
		secndpanel.add(bpView.getPanel());

		JSplitPane splitPanel = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, firstpanel, secndpanel);
		splitPanel.setDividerLocation(200);
		add(splitPanel);
		// Fin de creacion del frame ------------
		motor.lower();
	}
	class BotoneraPisosView
	{
		private JPanel mainPanel;
		BotoneraPisosView(Botonera[] botoneras)
		{
			mainPanel = new JPanel();
			mainPanel.setLayout(new BoxLayout(mainPanel,BoxLayout.Y_AXIS));

			boolean isOverFour = (4 < botoneras.length)?true:false;

			for (int i = botoneras.length-1; i > 0; i--)
			{
				JPanel panel = new JPanel();
				panel.setMaximumSize(new Dimension(200,150));
				if(isOverFour)
				{
					int xy = 750/(2*botoneras.length);
					botoneras[i].setBotonNewDimension(xy);
				}
				panel.add(botoneras[i].getView());
				mainPanel.add(panel);
			}
		}
		public JPanel getPanel()
		{
			return mainPanel;
		}
	}
	private JMenuBar AscensorMenu(ConfigMenuListener e)
	{
		JMenuBar mb = new JMenuBar();
		JMenu cfg 	= new JMenu("Configuration");
		mb.add(cfg);

		JMenuItem menuItem = new JMenuItem("Speed");
		menuItem.addActionListener(e);
		cfg.add(menuItem);
		menuItem = new JMenuItem("Pause Time");
		menuItem.addActionListener(e);
		cfg.add(menuItem);

		return mb;
	}
}

