import java.awt.geom.*;
import java.awt.*;
import javax.swing.JPanel;
import java.awt.Graphics;
import java.awt.Graphics2D;

public class CajaAscensorView extends JPanel
{
	//#################################
	// BEGIN declarations to use metric coordinate system (not pixels)
	// Do not worry for this code. It allows us use meter and not pixels
	// as distance metric. It also changes the axes so the origen is on the bottom left.
	public static int WIDTH = 350;  // caja escala width in pixels
	public static int HEIGHT = 700; // caja escala height in pixels
	public static int X_ORIGEN = (int)(WIDTH*0.1); // Caja escala origen (x,y) [m] will be on
	public static int Y_ORIGEN = (int)(HEIGHT*0.95); // (X_ORIGEN,Y_ORIGEN) of the panel space.
	public static AffineTransform SPACE_TRANSFORM;  // transforms (x,y) [m] in (X,Y) [pixels] of panel.
	public static Line2D.Double X_AXIS;  // lines to draw my world axes (singular axis, plural axes).
	public static Line2D.Double Y_AXIS;
	private static double AXES_SCALE = HEIGHT*0.95/16;  // 1 [m] equals AXES_SCALE [pixels]. 16 para tener 16 [m] en el 90% de HEIGHT
	static
	{
		SPACE_TRANSFORM = AffineTransform.getTranslateInstance(X_ORIGEN, Y_ORIGEN);
		SPACE_TRANSFORM.scale(AXES_SCALE,-AXES_SCALE);  // it also inverts direction of y-coordinate
		X_AXIS = new Line2D.Double(-0.1, 0, 2.5, 0);  // each axis length is 2 [m] from origen.
		Y_AXIS = new Line2D.Double(0, -0.1, 0, 2.0);
	}
	// END declarations to use metric coordinate system (not pixels)

	//#################################
	//#################################
	private Rectangle2D.Double view;	// Caja Ascensor
	private CabinaView cView;			// Cabina
	private LightView lView;			// Cabina
	private SensorView [] ssView;		// Sensor

	//#################################
	public CajaAscensorView(double x, double y, double width, double height, CabinaView cView, Sensor [] ss, Light light)
	{
		view = new Rectangle2D.Double(x, y, width, height);
		this.cView = cView;
		lView = light.getView();
		ssView = new SensorView [ss.length];
		for (int i = 0; i < ss.length; i++)
			ssView[i] = ss[i].getView();
	}

	//#################################
	public void paintComponent(Graphics g)
	{
		super.paintComponent(g);	// it paints the background
		Graphics2D g2d = (Graphics2D) g;
		g2d.transform(SPACE_TRANSFORM);  // after this transformation the panel space can be used in [m] and not pixels.
		g2d.setStroke(new BasicStroke(0.04f));
		
		// draw Caja Ascensor
		g2d.draw(view);

		// draw sensors
		for (int i = 0; i < ssView.length; i++)
			ssView[i].draw(g2d);
		
		// draw Cabina
		cView.draw(g2d);

		// draw Light
		lView.draw(g2d);
	}
}
